@@ -1,8 +1,9 @@
 /*********************************************************************
   Blosc - Blocked Shuffling and Compression Library
 
-  Author: Francesc Alted <francesc@blosc.org>
-  Creation date: 2018-01-03
+  Copyright (c) 2021  The Blosc Development Team <blosc@blosc.org>
+  https://blosc.org
+  License: BSD 3-Clause (see LICENSE.txt)
 
   See LICENSE.txt for details about copyright and rights to use.
 **********************************************************************/
@@ -16,4 +17,4 @@ unsigned char *fastcopy(unsigned char *out, const unsigned char *from, unsigned
 /* Same as fastcopy() but without overwriting origin or destination when they overlap */
 unsigned char* copy_match(unsigned char *out, const unsigned char *from, unsigned len);
 
-#endif //BLOSC_FASTCOPY_H
+#endif /* BLOSC_FASTCOPY_H */
